@@ -1,5 +1,5 @@
 AllenH <-
-function(Ps, q = 1, PhyloTree, Normalize = TRUE, CheckArguments = TRUE) 
+function(Ps, q = 1, PhyloTree, Normalize = TRUE, Prune = FALSE, CheckArguments = TRUE) 
 {
   if (CheckArguments)
     CheckentropartArguments()
@@ -9,6 +9,8 @@ function(Ps, q = 1, PhyloTree, Normalize = TRUE, CheckArguments = TRUE)
     # build a phylo object. Go through an hclust because as.phylo.phylog generates errors
     hTree <- stats::hclust(PhyloTree$Wdist^2/2, "average")
     Tree <- ape::as.phylo.hclust(hTree)
+    # edge lengths are divided by 2 during the conversion. See ?as.phylo.hclust
+    Tree$edge.length <- 2*Tree$edge.length
   } else {
     if (inherits(PhyloTree, "hclust")) {
       # build a phylo object
@@ -36,8 +38,21 @@ function(Ps, q = 1, PhyloTree, Normalize = TRUE, CheckArguments = TRUE)
     print(SpeciesNotFound)
   }
   
-  
-  # Branch lengths
+  # More species in the tree than in Ps?
+  SpeciesNotFound <- setdiff(Tree$tip.label, names(Ps))
+  if (length(SpeciesNotFound) > 0 ){
+    if (Prune) {
+      # Prune the tree to keep species in Ps only
+      Tree <- ape::drop.tip(Tree, SpeciesNotFound)
+    } else {
+      # Add species with probability 0 in Ps
+      ExtraPs <- rep(0, length(SpeciesNotFound))
+      names(ExtraPs) <- SpeciesNotFound
+      Ps <- c(Ps, ExtraPs)
+    }
+  }
+
+    # Branch lengths
   Lengths <- Tree$edge.length
   # Get unnormalized probabilities p(b)
   ltips <- sapply(Tree$edge[, 2], function(node) geiger::tips(Tree, node))
@@ -50,6 +65,7 @@ function(Ps, q = 1, PhyloTree, Normalize = TRUE, CheckArguments = TRUE)
   Branches <- Branches[Branches!=0]
   
   # Return normalized entropy
-  return ((-sum(Lengths*Branches^q*lnq(Branches, q)))/ifelse(Normalize, Tbar, 1))
-
+  entropy <- -sum(Lengths * Branches^q * lnq(Branches, q))/ifelse(Normalize, Tbar, 1)
+  names(entropy) <- "None"
+  return (entropy)
 }
