@@ -80,8 +80,8 @@ function (x, Correction = "None", Unveiling = "None", RCorrection = "Chao1", Jac
     spD <- spD/sum(spD)
   } else {
     # Integer abundances are required
-    NsInt <- as.integer(spD)
-    if (any(NsInt != spD)) warning("Integer abundance values are required to estimate community probabilities. Abundances have been rounded.")
+    NsInt <- round(spD)
+    if (any(abs(NsInt-spD) > sum(spD)*.Machine$double.eps)) warning("Integer abundance values are required to estimate community probabilities. Abundances have been rounded.")
     
     # Eliminate 0 and calculate elementary statistics
     Ns <- NsInt[NsInt > 0]
